The pyenv's official mirror Python archives

View on GitHub

### Welcome to the pyenv's official mirror of Python archives.

The python-build, is a plugin of pyenv that allows users to install python from source, uses http://yyuu.github.io/pythons for faster downloads.

You can enforce python-build to use optional mirror site with overriding `PYTHON_BUILD_MIRROR_URL`.

    $ export PYTHON_BUILD_MIRROR_URL="http://yoursite.example.com/pythons"
    $ pyenv install 2.7.7

The filenames of the archives must be the md5sum of its content. The following links are the contents of the pyenv's official mirror of Python archives.

### Stackless 2.7

- stackless-272-export.tar.bz2

### Stackless 3.2

- stackless-322-export.tar.bz2

### distribute

- distribute-0.6.32.tar.gz
- distribute-0.6.40.tar.gz
- distribute-0.6.43.tar.gz
- distribute-0.6.45.tar.gz

### setuptools

- setuptools-17.1.1.tar.gz

### pip

- pip-1.2.1.tar.gz
- pip-1.3.1.tar.gz
- pip-7.1.2.tar.gz

### GNU Readline

- readline-6.2.tar.gz
- readline-6.3.tar.gz

### OpenSSL

- openssl-1.0.1p.tar.gz
- openssl-1.0.1q.tar.gz
- openssl-1.0.2g.tar.gz